@@ -4,7 +4,7 @@
 """
 """
 STYLESHEETS = [data('css/bootstrap.min.css'),
-               data('css/bootstrap-responsive.min.css'),
+#               data('css/bootstrap-responsive.min.css'),
                data('css/custom.css'),
                data('cubes.bootstrap.css'),
                ]
