@@ -35,9 +35,9 @@ def _field_as_table(self, label, value, show_label=True,  tr=True, w=None):
 def _field_as_div(self, label, value, show_label=True, w=None):
     self.w(u'<div class="row-fluid">')
     if show_label and label:
-        self.w(u'<h6 class="span4">%s</h6>'% display_name(self._cw, label))
+        self.w(u'<h6 class="col-md-4">%s</h6>'% display_name(self._cw, label))
         value_cols = 8
     else:
         value_cols = 12
-    self.w(u'<div class="span%s">%s</div>' % (value_cols, value))
+    self.w(u'<div class="col-md-%s">%s</div>' % (value_cols, value))
     self.w(u'</div>')
